@@ -15,14 +15,13 @@ use Errorlog::TeeOutput;
 
 
 my $version ='$Id: Errorlog.pm 25638 2008-09-22 15:24:38Z anton $ ';
-our $VERSION="1.27";
+our $VERSION="1.28";
 #global variable, needed for TeeOutput
 our $SELF;
 
-
 sub end
 {
-  warn "Exitcode: $?";
+  warn  "Exitcode: $?"  if ($Baseobject::verbosity >=2 );
   if ($SELF->{fields}->{mailonfailure})
   {
     my $logbuffer=$SELF->{fields}->{logbuffer} if ($SELF->{fields}->{logbuffer});
@@ -32,13 +31,15 @@ sub end
 
 END
 {
-  return if ($SELF->{fields}->{skipEND});
-  if ($?)
+  my $status = $?;
+  return $status if ($SELF->{fields}->{skipEND});
+  if ($status)
   {
     # call shutdown to be able to call this method from an eternally living
     # perl interpretor such as modperl.
     end();
   }
+  $? = $status;
 }
 
 
